
/*
**  Copyright 2000 Compaq Computer Corporation
**  
**  COMPAQ Registered in U.S. Patent and Trademark Office.
**  
**  Confidential computer software.  Valid license from Compaq required for
**  possession, use or copying.  Consistent with FAR 12.211 and 12.212,
**  Commerical Computer Software, Computer Software Documentation, and
**  Technical Data for Commmerical Items are licensed to the U.S. Government
**  under vendor's standard commerical license.
*/

/*
**      This header file maps standard math library function names to 
**      Compaq's "fast" functions.
*/

#if defined(__cplusplus)
extern "C"
{

/*
** FAST double precision functions.
*/

extern double F_acos ( double );
extern double F_asin ( double );
extern double F_atan ( double );
extern double F_atan2 ( double, double );
extern double F_cos ( double );
extern double F_exp ( double );
extern double F_hypot ( double, double );
extern double F_log ( double );
extern double F_log10 ( double );
extern double F_pow ( double, double );
extern double F_sin ( double );
extern double F_sqrt ( double );
extern double F_tan ( double );

/*
** FAST single precision functions.
*/

extern float F_acosf ( float );
extern float F_asinf ( float );
extern float F_atan2f ( float, float );
extern float F_atanf ( float );
extern float F_cosf ( float );
extern float F_expf ( float );
extern float F_hypotf ( float, float );
extern float F_log10f ( float );
extern float F_logf ( float );
extern float F_powf ( float, float );
extern float F_sinf ( float );
extern float F_sqrtf ( float );
extern float F_tanf ( float );
}

static inline double acos ( double x ) { return    F_acos(x) ; } ;
static inline double asin ( double x ) { return    F_asin(x) ; } ;
static inline double atan ( double x ) { return    F_atan(x) ; } ;
static inline double atan2 ( double x, double y ) { return   F_atan2(x,y) ; } ;
static inline double cos ( double x ) { return     F_cos(x) ; } ;
static inline double exp ( double x ) { return     F_exp(x) ; } ;
static inline double hypot ( double x, double y ) { return   F_hypot(x,y) ; } ;
static inline double log ( double x ) { return     F_log(x) ; } ;
static inline double log10 ( double x ) { return   F_log10(x) ; } ;
static inline double pow ( double x, double y ) { return     F_pow(x,y) ; } ;
static inline double sin ( double x ) { return     F_sin(x) ; } ;
static inline double sqrt ( double x ) { return    F_sqrt(x) ; } ;
static inline double tan ( double x ) { return     F_tan(x) ; } ;

static inline float  acosf ( float x ) { return   F_acosf(x) ; } :
static inline float  asinf ( float x ) { return   F_asinf(x) ; } :
static inline float  atan2f ( float x, float y ) { return  F_atan2f(x,y) ; } :
static inline float  atanf ( float x ) { return   F_atanf(x) ; } :
static inline float  cosf ( float x ) { return    F_cosf(x) ; } :
static inline float  expf ( float x ) { return    F_expf(x) ; } :
static inline float  hypotf ( float x, float y ) { return  F_hypotf(x,y) ; } :
static inline float  log10f ( float x ) { return  F_log10f(x) ; } :
static inline float  logf ( float x ) { return    F_logf(x) ; } :
static inline float  powf ( float x, float y ) { return    F_powf(x,y) ; } :
static inline float  sinf ( float x ) { return    F_sinf(x) ; } :
static inline float  sqrtf ( float x ) { return   F_sqrtf(x) ; } :
static inline float  tanf ( float x ) { return    F_tanf(x) ; } :



#else


/*
** FAST double precision functions.
*/

extern double F_acos ( double );
extern double F_asin ( double );
extern double F_atan ( double );
extern double F_atan2 ( double, double );
extern double F_cos ( double );
extern double F_exp ( double );
extern double F_hypot ( double, double );
extern double F_log ( double );
extern double F_log10 ( double );
extern double F_pow ( double, double );
extern double F_sin ( double );
extern double F_sqrt ( double );
extern double F_tan ( double );

/*
** FAST single precision functions.
*/

extern float F_acosf ( float );
extern float F_asinf ( float );
extern float F_atan2f ( float, float );
extern float F_atanf ( float );
extern float F_cosf ( float );
extern float F_expf ( float );
extern float F_hypotf ( float, float );
extern float F_log10f ( float );
extern float F_logf ( float );
extern float F_powf ( float, float );
extern float F_sinf ( float );
extern float F_sqrtf ( float );
extern float F_tanf ( float );


#define acos    F_acos
#define asin    F_asin
#define atan    F_atan
#define atan2   F_atan2
#define cos     F_cos
#define exp     F_exp
#define hypot   F_hypot
#define log     F_log
#define log10   F_log10
#define pow     F_pow
#define sin     F_sin
#define sqrt    F_sqrt
#define tan     F_tan

#define acosf   F_acosf
#define asinf   F_asinf
#define atan2f  F_atan2f
#define atanf   F_atanf
#define cosf    F_cosf
#define expf    F_expf
#define hypotf  F_hypotf
#define log10f  F_log10f
#define logf    F_logf
#define powf    F_powf
#define sinf    F_sinf
#define sqrtf   F_sqrtf
#define tanf    F_tanf


#endif

